@@ -11,8 +11,9 @@ void *my_malloc(size_t size)
 
 	p = malloc(size);
 
-	if(!p) {
-		fprintf(stderr, "Failed to allocate: %d bytes of memory.\n");
+	if (!p) {
+		fprintf(stderr, "Failed to allocate: %zu bytes of memory.\n",
+			size);
 		exit(1);
 	}
 
